#[repr(i32)]pub enum BuiltinConfig {
S2t = 0,
T2s = 1,
S2tw = 2,
Tw2s = 3,
S2hk = 4,
Hk2s = 5,
S2twp = 6,
Tw2sp = 7,
T2tw = 8,
Tw2t = 9,
T2hk = 10,
Hk2t = 11,
}Expand description
All built-in OpenCC configurations
Variants
S2t = 0
Simplified to Traditional
T2s = 1
Traditional to Simplified
S2tw = 2
Simplified to Traditional (Taiwan)
Tw2s = 3
Traditional (Taiwan) to Simplified
S2hk = 4
Simplified to Traditional (Hong Kong)
Hk2s = 5
Traditional (Hong Kong) to Simplified
S2twp = 6
Simplified to Traditional (Taiwan) (including vocabulary conversion)
Tw2sp = 7
Traditional (Taiwan) (including vocabulary conversion) to Simplified
T2tw = 8
Traditional to Traditional (Taiwan)
Tw2t = 9
Traditional (Taiwan) to Traditional
T2hk = 10
Traditional to Traditional (Hong Kong)
Hk2t = 11
Traditional (Hong Kong) to Traditional
Implementations
Sourceimpl BuiltinConfig
impl BuiltinConfig
Sourcepub const fn to_filename(&self) -> &'static str
pub const fn to_filename(&self) -> &'static str
Converts the enum variant to the corresponding filename string
Sourcepub fn from_filename(filename: &str) -> Result<Self>
pub fn from_filename(filename: &str) -> Result<Self>
Converts a filename string to the corresponding enum variant